
#ifndef __LCL_STATIONCONFIG_H___
#define __LCL_STATIONCONFIG_H____

#include<stdarg.h>
#include <libxml/xmlmemory.h>
#include <libxml/parser.h>
#include <libxml/tree.h>
#include "xmlutils.h"
#include "station_config.h"

#define TRUE	1
#define FALSE	2

#define MAX_TAG_DATA		8

#define ACTIVE_MODE		1
#define POWER_SAVE_MODE		2

#define BSS_TYPE_INFRASTRUCTURE		1
#define BSS_TYPE_INDEPENDENT		2
#define BSS_TYPE_ANY			3

/* columns present in station config tables */
#define STATION_CONFIG_MAC                      "mac"
#define STATION_CF_POLLABLE                     "dot11-cf-pollable"
#define STATION_CONFIG_SSID                     "ssid"
#define STATION_CONFIG_RATE                     "rate"
#define STATION_CONFIG_BEACON_INT               "beacon-interval"
#define STATION_CONFIG_DTIM_PERIOD              "dtim-period"
#define STATION_CONFIG_AUTH_RESP_TIMEOUT        "dot11-authentication-response-time-out"
#define STATION_CONFIG_ASSOC_RESP_TIMEOUT       "dot11-association-response-time-out"
#define STATION_CONFIG_PRIV_OPT_IMPL            "dot11-privacy-option-implemented"
#define STATION_CONFIG_DISASSOC_REASON          "dot11-disassociate-reason"
#define STATION_CONFIG_DISASSOC_STATION         "dot11-disassociate-station"
#define STATION_CONFIG_DEAUTH_REASON            "dot11-deauthenticate-reason"
#define STATION_CONFIG_DEAUTH_STATION           "dot11-deauthenticate-station"
#define STATION_CONFIG_AUTH_FAIL_STATUS         "dot11-authenticate-fail-status"
#define STATION_CONFIG_AUTH_FAIL_STATION        "dot11-authenticate-fail-station"

struct stationconfig_info {
	char *sta_value;	
	int sta_value_len;
	char *cf_pollable;
	int cf_pollable_len;
	char *dtim_period;	
	int dtim_period_len;
	char *sid_value;	
	int sid_value_len;
	char *des_ssid;
	int des_ssid_len;
	char *beacon_int;
	int beacon_int_len;
	char *bss_value;
	int bss_value_len;
	char *radio_value;
	int radio_value_len;
	char *auth_rsp_tout;
	int auth_rsp_tout_len;
	char *priv_opt_impl;
	int priv_opt_impl_len;
	char *ass_res_to;
	int ass_res_to_len;
	char *oper_rate[MAX_TAG_DATA];
	int oper_rate_len[MAX_TAG_DATA];
	char *authfail_status;
	int authfail_status_len;
	char *authfail_sta;
	int authfail_sta_len;
	char *deauth_sta;
	int deauth_sta_len;
	char *deauth_res;
	int deauth_res_len;
	char *disass_sta;
	int disass_sta_len;
	char *disass_res;
	int disass_res_len;
};

static int CheckAndRetrieveDtimPeriodFromXml(xmlDocPtr);
static int CheckAndRetrieveStationIdFromXml(xmlDocPtr);
static int CheckAndRetrieveCFPollableFromXml(xmlDocPtr s_doc);
static int CheckAndRetrieveSSIDFromXml(xmlDocPtr);
static int CheckAndRetrieveBeaconPeriodFromXml(xmlDocPtr);
static int CheckAndRetrieveRadioValueFromBss(xmlDocPtr);
static int CheckAndRetrieveBssValueFromInterface(xmlDocPtr);
static int CheckAndRetrieveSuppRateFromXml(xmlDocPtr);
static int CheckAndRetrieveAuthRespFromXml(xmlDocPtr);
static int CheckAndRetrievePrivacyOptFromXml(xmlDocPtr);
static int CheckAndRetrieveAssociationRespFromXml(xmlDocPtr);
static int CheckAndRetrieveAuthFailStationFromXml(xmlDocPtr);
static int CheckAndRetrieveAuthFailStatusFromXml(xmlDocPtr);
static int CheckAndRetrieveDeAuthStationFromXml(xmlDocPtr);
static int CheckAndRetrieveDeAuthReasonFromXml(xmlDocPtr);
static int CheckAndRetrieveDisAssocStationFromXml(xmlDocPtr);
static int CheckAndRetrieveDisAssocReasonFromXml(xmlDocPtr);


static void lcl_dtimperiod_xml(xmlDocPtr, xmlNodePtr);
static void lcl_station_id_xml(xmlDocPtr, xmlNodePtr);
static void lcl_cf_pollable_xml(xmlDocPtr, xmlNodePtr);
static void lcl_desired_ssid_xml(xmlDocPtr, xmlNodePtr);
static void lcl_privacy_opt_xml(xmlDocPtr , xmlNodePtr );
static void lcl_beacon_int_xml(xmlDocPtr , xmlNodePtr );
static void lcl_radio_value_xml(xmlDocPtr, xmlNodePtr);
static void lcl_bss_value_xml(xmlDocPtr, xmlNodePtr);
static void lcl_supp_rate_xml(xmlDocPtr , xmlNodePtr );
static void lcl_auth_resp_xml(xmlDocPtr, xmlNodePtr);
static void lcl_asso_resp_xml(xmlDocPtr, xmlNodePtr);
static void lcl_dis_assoc_reason_xml(xmlDocPtr, xmlNodePtr);
static void lcl_dis_assoc_station_xml(xmlDocPtr, xmlNodePtr);
static void lcl_deauth_reason_xml(xmlDocPtr, xmlNodePtr);
static void lcl_deauth_station_xml(xmlDocPtr, xmlNodePtr);
static void lcl_auth_fail_sta_xml(xmlDocPtr, xmlNodePtr);
static void lcl_auth_fail_station_xml(xmlDocPtr, xmlNodePtr);

static int GetStationID(xmlDocPtr, int);
static void GetMediumOccupancyLimit(int);
static void GetCFPollable(xmlDocPtr, int);
static void GetCFPeriod(int);	
static void GetCFMaxDuration(int);
static void GetAuthenticationResponseTimeout(xmlDocPtr, int);
static void GetPrivacyOptionImplemented(xmlDocPtr, int);
static void GetPowerManagementMode(int);
static void GetDesiredSSID(xmlDocPtr, int);
static void GetDesiredBSSType(int);
static void GetOperationalRateSet(int);
static void GetBeaconPeriod(xmlDocPtr, int);
static void GetDTIMPeriod(xmlDocPtr, int);
static void GetAssociationResponseTimeout(xmlDocPtr, int);
static void GetDisAssociateReason(xmlDocPtr, int);
static int GetDisAssociateStation(xmlDocPtr, int);
static void GetDeAuthenticateReason(xmlDocPtr, int);
static int GetDeAuthenticateStation(xmlDocPtr, int);
static void GetAuthenticateFailStatus(xmlDocPtr, int);
static int  GetAuthenticateFailStation(xmlDocPtr, int);
static int GetMultiDomainCapabilityImplemented(int);
static int GetMultiDomainCapabilityEnabled(int);
static int GetCountryString(int);
#endif  /* __LCL_STATIONCONFIG_H___*/
