#ifndef LSQLQUERY_VALUE_H
#define LSQLQUERY_VALUE_H 1

#include "autoconf.h"

#ifdef CONFIG_OAP_DEBUG
#include <stdio.h>
#endif

typedef struct apc_web_value apc_web_value_t;

/* struct to hold values to broker request and responses from apconfig */
/* there may be multiple related values that are strung up by the next ptr */
/* e.g.
 * (field string) --peer-->
 *      |
 *    next
 *      |
 *      v
 *
 *
 * this is a set of three ip routes
 * (dest 10.10.10.0) --next-->(mask 255.255.255.0) --next-->(gateway 10.10.10.1)
 *         |
 *        peer
 *         |
 *         v
 * (dest 172.16.0.0) --next-->(mask 255.255.255.0) --next-->(gateway 172.16.0.1)
 *         |
 *        peer
 *         |
 *         v
 * (dest 0.0.0.0) --next--> (mask 0.0.0.0) --next--> (gateway 192.168.1.1)
 */
struct apc_web_value {
	char *field;			/* this is the key */
	char *string;			/* this is the value */
	apc_web_value_t *peer;          /* point to the peer value in the list
					 * most likely to a value with the same
					 * field
					 */
	apc_web_value_t *next;          /* point to an associated value
                                         * most likely with a different field
					 */
};

/**
 * Destroys a set of apc_web_value_t.
 * Args: an apc_web_value_t.
 * Returns: nothing.
 * Side-effect: frees memory.
 */
void apc_web_destroy_value(apc_web_value_t *value);
void apc_web_destroy_one_value(apc_web_value_t *value);
char *apc_web_get_value_string_and_destroy_value(apc_web_value_t *value);

apc_web_value_t *apc_web_new_value_solo(const char *field,
					const char *string);
apc_web_value_t *apc_web_new_value(const char *field,
				   const char *string,
				   apc_web_value_t *prev_value);
apc_web_value_t *apc_web_new_value_with_peer(const char *field,
					     const char *string,
					     apc_web_value_t *prev_value,
					     apc_web_value_t *peer_value);
apc_web_value_t *apc_web_new_value_before_with_peer(const char *field,
						    const char *string,
						    apc_web_value_t *next,
						    apc_web_value_t *peer);
apc_web_value_t *apc_web_new_value_before(const char *field,
					  const char *string,
					  apc_web_value_t *next);
apc_web_value_t *apc_web_duplicate_value(apc_web_value_t *value);

int apc_web_value_count_next(apc_web_value_t *value);

#ifdef CONFIG_OAP_DEBUG
int apc_web_print_value(FILE *stream, apc_web_value_t *value);
#endif

#endif /* LSQLQUERY_VALUE_H */
